from .scraper import Scraper


class Player:
    """
    The Player class contains all the functions that extract data related to players
    """

    # Attributes
    # ----------
    # player_id : int
    #     ID of the player obtained from Cricinfo

    # Methods
    # -------
    # career_summary(query_params)
    #     Returns the career summary stats of the player.

    # inn_list(query_params)
    #     Returns the list of innings played by the player and stats.

    # match_list(query_params)
    #     Returns the list of matches played by the player and stats.

    # cumulative_avg(query_params)
    #     Returns the cumulative average of all matches played.

    # reverse_cumulative(query_params)
    #     Returns the reverse cumulative average of all matches played.

    # series_avg(query_params)
    #     Returns the average scores and bowling stats for each series.

    # ground_avg(query_params)
    #     Returns the average scores and bowling stats in each ground played.

    # match_results(query_params)
    #     Returns the results of all matches played.

    # match_awards(query_params)
    #     Returns the awards earned in all matches.

    # series_awards(query_params)
    #     Returns the awards earned in all series.

    # partnership_summary(query_params)
    #     Returns the summary stats of all partnerships.

    # partnership_list(query_params)
    #     Returns the list of all partnerships and stats.

    # dismissal_summary(query_params)
    #     Returns the summary of all batting dismissals under various groupings.

    # bowler_summary(query_params)
    #     Returns the summary of stats against all bowlers faced.

    # fielder_summary(query_params)
    #     Returns the summary of stats and dismissals against fielding players.

    # dismissal_list(query_params)
    #     Returns the list of all dismissals.

    # dism_summary(query_params)
    #     Returns the summary of all wickets by the player.

    # batsman_summary(query_params)
    #     Returns the summary stats of all batters dismissed.

    # fielder_summary(query_params)
    #     Returns the summary stats dismissals by fielders.

    # wickets_list(query_params)
    #     Returns the list of all wickets taken.

    def __init__(self, player_id):
        """
        :param player_id: The player id obtained from the Cricinfo website
        :type player_id: int
        """
        # Default results parameter required by cricinfo in all queries
        self.query = {"template": "results"}
        self.player_id = player_id
        self.cric_data = []

    def career_summary(self, query_params):
        """Returns the career summary stats of the player.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        cric_data : pandas.Dataframe
            A dataframe containing the query results

        Examples
        -------
        .. code-block:: python

            player = player.Player(49764)
            query_params = {
                'class' : '1',
                'type' : 'allround'
            }

            cric_data = player.career_summary(query_params)
            print(cric_data.head())
        """
        # Update default query dict with query_params dict
        self.query.update(query_params)
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def inn_list(self, query_params):
        """Returns the list of innings played by the player and stats.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "innings"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def match_list(self, query_params):
        """Returns the list of matches played by the player and stats.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "match"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def cumulative_avg(self, query_params):
        """Returns the cumulative average of all matches played.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "cumulative"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def reverse_cumulative(self, query_params):
        """Returns the reverse cumulative average of all matches played.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "reverse_cumulative"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def series_avg(self, query_params):
        """Returns the average scores and bowling stats for each series.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "series"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def ground_avg(self, query_params):
        """Returns the average scores and bowling stats in each ground played.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "ground"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def match_results(self, query_params):
        """Returns the results of all matches played.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "results"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def match_awards(self, query_params):
        """Returns the awards earned in all matches.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "awards_match"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    def series_awards(self, query_params):
        """Returns the awards earned in all series.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "awards_series"
        scraper = Scraper(self.query)
        cric_data = scraper.getPlayerData(self.player_id)

        return cric_data

    # BATTING
    def partnership_summary(self, query_params):
        """Returns the summary stats of all partnerships.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return batting data will not work with bowling parameters
        """
        self.query.update(query_params)
        self.query["view"] = "fow_summary"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Partnership summary is only available for batting data")

    def partnership_list(self, query_params):
        """Returns the list of all partnerships and stats.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return batting data will not work with bowling parameters
        """
        self.query.update(query_params)
        self.query["view"] = "fow_list"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Partnership list is only available for batting data")

    def dismissal_summary(self, query_params):
        """Returns the summary of all batting dismissals under various groupings.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return batting data will not work with bowling parameters
        """
        self.query.update(query_params)
        self.query["view"] = "dismissal_summary"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Dismissal summary is only available for batting data")

    def bowler_summary(self, query_params):
        """Returns the summary of stats against all bowlers faced.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return batting data will not work with bowling parameters
        """
        self.query.update(query_params)
        self.query["view"] = "bowler_summary"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Bowler summary is only available for batting data")

    def fielder_summary(self, query_params):
        """Returns the summary of stats and dismissals against fielding players.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return batting data will not work with bowling parameters
        """
        self.query.update(query_params)
        self.query["view"] = "fielder_summary"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Fielder summary is only available for batting data")

    def dismissal_list(self, query_params):
        """Returns the list of all dismissals.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return batting data will not work with bowling parameters
        """
        self.query.update(query_params)
        self.query["view"] = "dismissal_list"
        if self.query["type"] == "batting":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Dismissal list is only available for batting data")

    # BOWLING
    def dism_summary(self, query_params):
        """Returns the summary of all wickets by the player.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return bowling data will not work with batting parameters
        """
        self.query.update(query_params)
        self.query["view"] = "dismissal_summary"
        if self.query["type"] == "bowling":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Dismissal summary is only available for bowling data")

    def batsman_summary(self, query_params):
        """Returns the summary stats of all batters dismissed.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return bowling data will not work with batting parameters
        """
        self.query.update(query_params)
        self.query["view"] = "batsman_summary"
        if self.query["type"] == "bowling":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Batsman summary is only available for bowling data")

    def fielder_summary(self, query_params):
        """Returns the summary stats dismissals by fielders.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return bowling data will not work with batting parameters
        """
        self.query.update(query_params)
        self.query["view"] = "fielder_summary"
        if self.query["type"] == "bowling":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Fielder summary is only available for bowling data")

    def wickets_list(self, query_params):
        """Returns the list of all wickets taken.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results

        Raises
        ------
        Exception
            Functions that return bowling data will not work with batting parameters
        """
        self.query.update(query_params)
        self.query["view"] = "dismissal_list"
        if self.query["type"] == "bowling":
            scraper = Scraper(self.query)
            cric_data = scraper.getPlayerData(self.player_id)

            return cric_data
        raise Exception("Wickets list is only available for bowling data")



"""Cricguru

This package contains functions for retrieving data from the Statsguru data query on ESPN Cricinfo. The main
classes cover teams and players data. The results are returned as a Pandas dataframe in order to facilitate
data analysis on cricket data.

"""



from .scraper import Scraper


class Team:
    """
    The Team class contains all the functions that extract overall and teams related data.
    """

    # Methods
    # -------
    # overall(query_params, limit=100)
    #     Returns overall figures for all matches played by each team.

    # inn_by_inn(query_params, limit=100)
    #     Returns match results for each innings.

    # matchtot(query_params, limit=100)
    #     Returns total scores for each team by match.

    # matchres(query_params, limit=100)
    #     Returns results of each match.

    # series_avg(query_params, limit=100)
    #     Returns the average scores and stats for each series.

    # ground_avg(query_params, limit=100)
    #     Returns the average scores and stats based on ground played in.

    # by_host(query_params, limit=100)
    #     Returns the overall stats for each team by host team.

    # by_opp(query_params, limit=100)
    #     Returns the overall stats for each team against each opposition team.

    # by_year(query_params, limit=100)
    #     Returns the overall stats for each team by year.

    # by_season(query_params, limit=100)
    #     Returns the overall stats for each team by season.

    # overall_extras(query_params, limit=100)
    #     Returns the overall extras scored by each team and other stats related to extras.

    # extras_inn(query_params, limit=100)
    #     Returns the extras scored by innings.
    def __init__(self):
        # Default query parameters for team data
        self.query = {"type": "team", "template": "results"}

    # OVERALL FIGURES
    def overall(self, query_params, limit=100):
        """Returns the overall figures for all matches played by each team.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.
        """
        # Update default query dict with query_params dict
        self.query.update(query_params)
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # INNINGS BY INNINGS
    def inn_by_inn(self, query_params, limit=100):
        """Returns match results for each innings.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        # Each data function has a unique view parameter ex. innings
        self.query["view"] = "innings"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # MATCH TOTALS
    def matchtot(self, query_params, limit=100):
        """Returns total scores for each team by match.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "match"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # MATCH RESULTS
    def matchres(self, query_params, limit=100):
        """Returns the overall results of each match.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "results"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # SERIES AVERAGE
    def series_avg(self, query_params, limit=100):
        """Returns the average scores and stats for each series.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "series"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # GROUND AVERAGE
    def ground_avg(self, query_params, limit=100):
        """Returns the average scores and stats based on ground played in.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "ground"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # RESULTS BY HOST COUNTRY
    def by_host(self, query_params, limit=100):
        """Returns the overall stats for each team by host team.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "host"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # RESULTS BY OPPOSITION
    def by_opp(self, query_params, limit=100):
        """Returns the overall stats for each team against each opposition team.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "opposition"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # BY YEAR
    def by_year(self, query_params, limit=100):
        """Returns the overall stats for each team by year.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "year"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # BY SEASON
    def by_season(self, query_params, limit=100):
        """Returns the overall stats for each team by season.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "season"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # OVERALL EXTRAS
    def overall_extras(self, query_params, limit=100):
        """Returns the overall extras scored by each team and other stats related to extras.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "extras"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data

    # EXTRAS BY INNINGS
    def extras_inn(self, query_params, limit=100):
        """Returns the extras scored by innings.

        Parameters
        ----------
        query_params : dict[str, list, or set or dict]
            A dictionary containing all the query parameters.
        limit : int
            The data limit for number of records returned. Default limit is 100.

        Returns
        -------
        pandas.Dataframe
            A dataframe containing the query results
        """
        self.query.update(query_params)
        self.query["view"] = "extras_innings"
        scraper = Scraper(self.query)
        cric_data = scraper.getTeamData(limit)

        return cric_data



import requests
from bs4 import BeautifulSoup
import pandas as pd
from dotenv import load_dotenv
import os
from urllib.parse import urlencode
from collections import OrderedDict

load_dotenv()

# Get all data for given query parameters
# ------------- Note -------------
# Default row limit set to 200 | 12/03/2022
class Scraper:
    def __init__(self, query_params):
        self.query_params = query_params

    def getTeamData(self, limit=100):
        encoded_params = urlencode(self.query_params)
        # URLS
        url = 'https://stats.espncricinfo.com/ci/engine/stats/index.html?{0}&page={1}'

        page_counter = 0
        row_limit = 0
        cric_data_pages = []

        # Scraper loop
        while True:
            page_counter += 1
            
            url = url.format(encoded_params, str(page_counter))
            
            dfs = pd.read_html(url)
            print(page_counter)
            row_limit += len(dfs[2])

            if row_limit < limit:
                cric_data_pages.append(dfs[2])
            elif page_counter == 1 and len(dfs[2]) > limit:
                cric_data_pages.append(dfs[2].iloc[:limit])
                break
            else:
                cric_data_pages.append(dfs[2].iloc[:limit-len(dfs[2])])
                break

        cric_data = pd.concat(cric_data_pages)
        cric_data = cric_data.loc[:, ~cric_data.columns.str.startswith('Unnamed')]
        return cric_data

    def getPlayerData(self, player_id=0):
        url = 'https://stats.espncricinfo.com/ci/engine/player/{0}.html?{1}'
        encoded_params = urlencode(self.query_params)

        url = url.format(str(player_id), encoded_params)
        dfs = pd.read_html(url)
        cric_data = dfs[3]
        cric_data = cric_data.loc[:, ~cric_data.columns.str.startswith('Unnamed')]
        return cric_data


# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['cricguru']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2', 'pandas>=1.5.2,<2.0.0']

setup_kwargs = {
    'name': 'cricguru',
    'version': '1.3.3',
    'description': '',
    'long_description': '<h2 align="center">Cricguru</h2>\n\n## Overview\nCricguru is a data extraction module for extracting data from the Statsguru data query on Cricinfo. I was inspired to build a simple tool to extract dataframes from statsguru for analyzing cricket data and was finding it difficult to obtain overall figures from the website as they did not have an API for it. Cricinfo has a large variety of cricket data for all classes of cricket matches and also in-depth player data. However without an API it is impossible to extract any useful information from it. Hence this module has functions to easily get the cricket data we want without having to manually scrape the website. The data output is currently returned in the form of Pandas dataframes. You can find the full documentation <a href="https://cricguru.readthedocs.io/en/stable/overview.html" target="_blank">here</a>.\n\n## Team Data\nData by team can be obtained for the three main classes of cricket formats which are <b>Test</b>, <b>One-day</b> and <b>T20</b>. Excluding the class argument would return the overall data. In order to filter by teams and opposition you must provide one of the following ids to the team and opposition arguments respectively for some popular teams.\n\n{"all teams": "", "Afghanistan": "40", "Australia": "2", "Bangladesh": "25", "England": "1", "ICC World XI": "140", "India": "6", "Ireland": "29", "New Zealand": "5", "Pakistan": "7", "South Africa": "3", "Sri Lanka": "8", "West Indies": "4", "Zimbabwe": "9"}\n\n## Player Data\nData by player can be obtained for the same classes mentioned above. The player class however requires a player id which can be obtained from Cricinfo by selecting a team followed by a player from that team. For example <a href="https://www.espncricinfo.com/player/angelo-mathews-49764">Angelo Mathew\'s</a> id is 49764 which can be found appended to the url of the player\'s stats page on Cricinfo.\n\n## Built With\nThis project primarily uses Python 3.8 in combination with Pandas. Pandas is used to get the tables directly from the Statsguru query pages and convert them to dataframes. Urllib is used to format the url and append the query parameters. Poetry is used for packaging and publishing.\n\n## Getting Started\nYou can install the package using the following command.\n```sh\npip install cricguru\n```\n\n## Usage\nYou can get overall figures for all teams with the following. You must pass in the query parameters in a dictionary as shown.\n```sh\nfrom cricguru import team\n\nteam = team.Team()\nquery_params = {"template": "results"}\ncric_data = team.overall(query_params)\n\n#Returns a pandas dataframe\ncric_data.head()\n```\nFor player data you have to provide the player id to initialize the player object and then call the function for the type of data you require. You have to specify what type of player data you need such as allround, batting or bowling.\n\n```sh\nfrom cricguru import player\n\nplayer = player.Player(49764)\nquery_params = {\n    \'class\' : \'1\',\n    \'type\' : \'allround\'\n}\n\ncric_data = player.career_summary(query_params)\nprint(cric_data.head())\n```\n\n## Contributing\nThis is an amateur project at best and I am still a complete beginner to Python and would greatly welcome any suggestions, advice, constructive criticism, best practices or contributions to the project.  Simply open a pull request or issue and I will check it out.\n\n## Contact\nYou can also contact me at pavithranthilakanathan@gmail.com or on twitter - <a href="https://twitter.com/pavin_v1">@pavin_v1</a>\n\n## License\nDistributed under the MIT license. See `LICENSE.md\' for more information.\n\n## Acknowledgements\n<ul>\n  <li><a href="https://www.espncricinfo.com/">ESPN Cricinfo</a></li>\n</ul>\n\n## Todo\n<ul>\n  <li>100% code coverage</li>\n  <li>Additional data formats</li>\n</ul>\n',
    'author': 'Pavithran',
    'author_email': 'pavithranthilakanathan@gmai.com',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'https://github.com/puppetmaster12/cricguru',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
